
/*
  +-----------------------------------------------------------------------+
  | (C) ADDI-DATA GmbH          Dieselstrae 3       D-77833 Ottersweier  |
  +-----------------------------------------------------------------------+
  | Tel : +49 (0) 7223/9493-0     | email    : info@addi-data.com         |
  | Fax : +49 (0) 7223/9493-92    | Internet : http://www.addi-data.com   |
  +-------------------------------+---------------------------------------+
  | Project     : API  ADDI-DATA  |     Compiler   : BORLANDC/MICROSOFT C |
  | Module name : UTILITY.H       |     Version    : 3.1     / 6.0        |
  |                               |                                       |
  |                               |                                       |
  +-------------------------------+---------------------------------------+
  | Author : Guinot C.                      Date :11/01/2001              |
  +-----------------------------------------------------------------------+
  | Description   : Header file for the ADDI-DATA Utility functions       |
  +-----------------------------------------------------------------------+
  |                             UPDATES                                   |
  +----------+-----------+------------------------------------------------+
  |   Date   |   Author  |          Description of updates                |
  +----------+-----------+------------------------------------------------+
  | 09.08.01 | S. Weber  | 0701-0214 -> 0801-0216 : Counter implementation|
  |          |           |                                                |
  +----------+-----------+------------------------------------------------+
  | 21/11/01 |R. HILPERT | 1101/0218 -> 1101/0219 : Add APCI-1500         |
  |          |           | + APCI-3120 + APCI-3001.                       |
  +----------+-----------+------------------------------------------------+
  | 28/03/03 | C.Guinot  | Export a function to read the header of the    |
  |          |           | board and store it in a WORD array             |
  |          |           | new function : i_UTILITY_ReadBoardHeader       |  
  |          |           | i_UTILITY_TestIfHeaderMustBeReadFromFile       |
  +----------+-----------+------------------------------------------------+
  | 31/03/03 | C.Guinot  | The Open function need too much time.          | 
  |          |           | We need the Device Nbr of the board from the   |
  |          |           | registry                                       | 
  |          |           | See change in                                  |
  |          |           | i_UTILITY_ReadRegistryBoardInformations        | 
  +----------+-----------+------------------------------------------------+ 
  | 23/06/03 | R. HILPERT| Add the read of the header of a                | 
  |          |           | NoHeaderOnBoard Board from a file              |  
  +----------+-----------+------------------------------------------------+ 
  | 23/04/04 | C.Guinot  | implementation of the APCI-1648/APCI-1696      |
  |          |           | Add function to configure the Dig I/O          |
  +----------+-----------+------------------------------------------------+ 
  | 23/01/06 | C.Guinot  | MX Implementation                              |
  +----------+-----------+------------------------------------------------+ 
*/

#ifndef ADDIDATA_UTILITY_HEADER
   #define ADDIDATA_UTILITY_HEADER



/* Error define */
#define UTILITY_BOARD_INDEX_NOT_AVAILABLE                 -2001  
#define UTILITY_FUNCTIONALITY_INDEX_NOT_AVAILABLE         -2002  
#define UTILITY_MODULE_INDEX_NOT_AVAILABLE                -2003
#define UTILITY_INPUT_INDEX_NOT_AVAILABLE                 -2004
#define UTILITY_FUNCTIONALITY_NOT_AVAILABLE               -2005    
#define UTILITY_EXIT_MODE_NOT_AVAILABLE                   -2006
#define UTILITY_CREATE_FILE_ERROR                         -2007
#define UTILITY_WRITE_FILE_ERROR                          -2008
#define UTILITY_OPEN_FILE_ERROR                           -2009
#define UTILITY_READ_FILE_ERROR                           -2010

#define UTILITY_CONFIGURATION_HEADER_NOT_AVAILABLE        -2011
#define UTILITY_WRITE_EEPROM_ERROR                        -2012

#define UTILITY_MEMORY_ALLOCATION_ERROR                   -2013

#define ADDIDATA_EXIT_WITH_SAVE        1
#define ADDIDATA_EXIT_WITHOUT_SAVE     0


/*************************************************************************/
/* Utility.c                                                             */
/*************************************************************************/

_INT_ i_UTILITY_SelectWin32System (PINT      pi_ErrorCode);

_INT_ i_UTILITY_InitialiseADDIDriverRegistryInformation (INT i_SystemSelection,
                                                         PWORD pw_NbrOfADDIDriverBoard,
                                                         PWORD pw_NbrOfFunctionality);

_INT_ i_UTILITY_ActualiseADDIDriverRegistryStructureInformation (INT i_SystemSelection,
                                                                 PWORD pw_NbrOfADDIDriverBoard,
                                                                 PWORD pw_NbrOfFunctionality);

_INT_ i_UTILITY_TestIfRegistryInformationAvailable (WORD w_Board,
                                                    PBYTE pb_RegistryInformationAvailability);

_INT_ i_UTILITY_GetFunctionalityString (WORD w_Functionality,
                                        PCHAR pc_FunctionalityString);

_INT_ i_UTILITY_GetFunctionalityAvailability (WORD w_Board,
                                              WORD w_Functionality,
                                              PBYTE pb_FunctionalityAvailability);

_INT_    i_UTILITY_GetBoardResourceInformation (WORD     w_Board,
                                                PCHAR   pc_BoardName, 
                                                // Begin CG 24/01/2006 : MX implementation
                                                PBYTE pb_BusType,
                                                PCHAR   pc_IPAddress,
                                                PCHAR   pc_SerialNumber,
                                                // End CG 24/01/2006 : MX implementation 
                                                PDWORD pdw_BoardAddress,
                                                PBYTE   pb_BoardInterrupt,
                                                PCHAR   pc_PCISlotNumberInformation);

_INT_ i_UTILITY_GetNumberOfModule (WORD w_Board,
                                   WORD w_Functionality,
                                   PWORD pw_NbrOfModule);

_INT_ i_UTILITY_GetFunctionalityInformation (WORD w_Board,
                                             WORD w_Functionality,
                                             WORD w_Module,      
                                             PWORD pw_VirtualModule,
                                             PWORD pw_RealModule,
// Begin: RH 29/05/02
                                             PWORD pw_ConceptOfModule,
// End: RH 29/05/02
                                             PWORD pw_NbrOfRessource, 
                                             PWORD pw_VirtualIndexOfTheFirst,
                                             PWORD pw_VirtualIndexOfTheLast,
                                             PCHAR pc_RessourceInfoString,
                                             PWORD pw_RealIndexOfTheFirst,
                                             PWORD pw_RealIndexOfTheLast,
                                             PCHAR  pc_InformationString);

_INT_ i_UTILITY_ReleaseADDIDriverRegistryInformation (INT i_SystemSelection,
                                                      WORD w_ExitMode);

_INT_ i_UTILITY_InitialiseConfigurationStructureInformation (WORD    w_Board,
                                                             PBYTE   pb_ConfigurationPossible,
                                                             PBYTE   pb_DefaultConfigurationAvailable);

_INT_ i_UTILITY_SetAnalogInputModuleMode (WORD       w_Module,
                                          WORD       w_ModuleMode);


_INT_ i_UTILITY_SetAnalogInputSingleDiffMode (WORD   w_Module,
                                              WORD   w_SingleDiffMode);

_INT_ i_UTILITY_SetAnalogInputChannelSingleDiffMode (WORD  w_Module,
                                                     WORD  w_Channel,
                                                     WORD  w_SingleDiffMode);

_INT_ i_UTILITY_SetAnalogInputType (WORD     w_Module,
                                    WORD     w_Input,
                                    BYTE     b_InputType);

_INT_ i_UTILITY_SetAnalogInputTypePrecision (WORD    w_Module,
                                             WORD    w_Input,
                                             BYTE    b_InputTypePrecision);

_INT_ i_UTILITY_SetAnalogInputTypeValue (WORD        w_Module,
                                         WORD        w_Input,
                                         WORD        w_InputTypeValue);

_INT_ i_UTILITY_GetAnalogInputModuleNumber(PWORD pw_Number);

_INT_ i_UTILITY_GetAnalogInputNumber(WORD w_Module,PWORD pw_Number);

_INT_ i_UTILITY_GetAnalogInputMaxDiffNumber(WORD w_Module,PWORD pw_Number);


_INT_ i_UTILITY_GetAnalogInputModuleModeAvailability (WORD  w_Module,
                                                   WORD  w_ModuleMode,
                                                   BYTE  b_SingleDiffSelection,
                                                   PBYTE pb_ModuleModeAvailability);


_INT_ i_UTILITY_GetAnalogInputSingleDiffModeAvailability (WORD w_Module,
                                                          PBYTE pb_SingleDiffModeAvailability);

_INT_ i_UTILITY_GetAnalogInputSingleChannelDiffModeAvailability (WORD  w_Module,
                                                                 PBYTE pb_SingleDiffModeAvailability);


_INT_ i_UTILITY_GetAnalogInputTypeAvailability (WORD w_Module,
                                                WORD w_Input,
                                                BYTE b_InputType,
                                                PBYTE pb_InputTypeAvailability);

_INT_ i_UTILITY_GetAnalogInputTypePrecisionAvailability (WORD        w_Module,
                                                         WORD        w_Input,
                                                         BYTE        b_InputType,
                                                         BYTE        b_InputTypePrecision,
                                                         PBYTE       pb_InputTypePrecisionAvailability);

_INT_ i_UTILITY_GetAnalogInputTypeValueAvailability (WORD    w_Module,
                                                     WORD    w_Input,
                                                     BYTE    b_InputType,
                                                     BYTE    b_InputTypePrecision,
                                                     PBYTE   pb_InputTypeValueAvailability);

_INT_ i_UTILITY_GetAnalogInputModuleModeDefault (WORD        w_Module,
                                                 PWORD       pw_ModuleMode);

_INT_ i_UTILITY_GetAnalogInputSingleDiffModeDefault (WORD    w_Module,
                                                     PWORD   pw_SingleDiffMode);

_INT_ i_UTILITY_GetAnalogInputChannelSingleDiffModeDefault (WORD  w_Module,
                                                            WORD  w_Channel,
                                                            PWORD pw_SingleDiffMode);

_INT_ i_UTILITY_GetAnalogInputTypeDefault (WORD      w_Module,
                                           WORD      w_Input,
                                           PBYTE     pb_InputType);

_INT_ i_UTILITY_GetAnalogInputTypePrecisionDefault (WORD     w_Module,
                                                    WORD     w_Input,
                                                    PBYTE    pb_InputTypePrecision);

_INT_ i_UTILITY_GetAnalogInputTypeValueDefault (WORD         w_Module,
                                                WORD         w_Input,
                                                PWORD        pw_InputTypeValue);

// Begin SW 0701-0214 -> 0801-0216 : Counter implementation
_INT_ i_UTILITY_GetTimerCounterWatchdogModuleNumber           (PWORD pw_Number);

_INT_ i_UTILITY_GetTimerCounterWatchdogModuleModeAvailability (WORD   w_Module,
                                                               PWORD pw_AvailableModuleMode);
// Begin: RH 29/05/02
_INT_ i_UTILITY_GetTimerCounterWatchdogModuleProperty (WORD   w_Module,
                                                               PWORD pw_Property);
// End: RH 29/05/02

_INT_ i_UTILITY_GetSelectedTimerCounterWatchdogModuleMode     (WORD   w_Module,
                                                               PWORD pw_ModuleMode);

_INT_ i_UTILITY_SetTimerCounterWatchdogModuleMode             (WORD  w_Module,
                                                               WORD  w_ModuleMode);
// End SW 0701-0214 -> 0801-0216 : Counter implementation


// Begin 23/04/04 CG : add APCI-1648/APCI-1696
_INT_ i_UTILITY_GetDigIOModuleNumber(PWORD pw_Number);

_INT_ i_UTILITY_GetDigIOModuleModeAvailability (WORD   w_Module,
                                                PWORD pw_AvailableModuleMode);

_INT_ i_UTILITY_GetSelectedDigIOModuleMode (WORD   w_Module,
                                            PWORD pw_ModuleMode);

_INT_ i_UTILITY_SetDigIOModuleMode (WORD  w_Module,
                                    WORD  w_ModuleMode);

// End 23/04/04 CG : add APCI-1648/APCI-1696

_INT_ i_UTILITY_SaveConfigurationHeaderInformationInFile (PCHAR pc_FileName);

_INT_ i_UTILITY_ReloadConfigurationHeaderInformationFromFile (PCHAR pc_FileName);

_INT_    i_UTILITY_ReleaseConfigurationStructureInformation (WORD w_Board,
                                                             // Begin CG 11/05/04 : Read the header from the file : APCI-1648/APCI-1696
                                                             INT i_SystemSelection,
                                                             // End CG 11/05/04 : Read the header from the file : APCI-1648/APCI-1696
                                                             WORD w_ExitMode);

_INT_ i_UTILITY_DeleteADDIDriverRegistryInformation (INT i_SystemSelection,
                                                     INT   i_BoardID);

// Begin: RH 21/11/01 1101/0218 -> 1101/0219 : Add APCI-1500 + APCI-3120 + APCI-3001

_INT_ i_UTILITY_GetMultiBoardListRegistered  (INT i_SystemSelection,
                                                                  PINT  pi_NumberOfBoardIndex,
                                                                  PINT  pi_BoardIndexArray,
                                                                  PINT  pi_HeaderInformationIndexArray);

_INT_ i_UTILITY_GetMultiBoardListFound   (INT i_SystemSelection,
                                                                  PINT  pi_NumberOfBoardIndex,
                                                                  PINT  pi_BoardIndexArray);

_INT_ i_UTILITY_GetMultiHeaderBoardHeaderInformationListTitleFromRegistry (INT i_SystemSelection,
                                                                  INT   i_BoardID,
                                                                  PCHAR pc_TitleOfHeaderInformationList);

_INT_ i_UTILITY_GetMultiHeaderBoardHeaderInformationTitleFromRegistry (INT i_SystemSelection,
                                                                  INT   i_BoardID,
                                                                  INT   i_HeaderInformationIndex,
                                                                  PCHAR pc_TitleOfHeaderInformation);

_INT_ i_UTILITY_GetMultiHeaderBoardHeaderInformationFileNameFromRegistry  (INT i_SystemSelection,
                                                                  INT   i_BoardID,
                                                                  INT   i_HeaderInformationIndex,
                                                                  PCHAR pc_FileNameOfHeaderInformation);

_INT_ i_UTILITY_GetMultiHeaderBoardHeaderInformationTextFromRegistry  (INT i_SystemSelection,
                                             INT   i_BoardID,
                                             INT   i_HeaderInformationIndex,
                                             INT   i_TextLineIndex,
                                             PCHAR pc_TextHeaderInformationLine);

_INT_ i_UTILITY_GetFileSize     (PWORD  pw_SizeOfTheFile,
                                             PCHAR pc_HeaderInformationFileName);

_INT_ i_UTILITY_CompareHeaderInformation  (INT i_SystemSelection,
                                             INT   i_BoardID,
                                             PCHAR pc_HeaderInformationFileName);

_INT_ i_UTILITY_WritePartOfHeaderInformation  (INT i_SystemSelection,
                                             INT   i_BoardID,
                                             PCHAR pc_HeaderInformationFileName,
                                             WORD   w_BeginIndexToWrite,
                                             WORD   w_SizeToWrite);


_INT_   i_UTILITY_ReadRegistryBoardInformations    (INT      i_SystemSelection,
                                                    INT      i_BoardID,
                                                    PCHAR   pc_BoardName,
                                                    // Begin CG 23/01/2006 : MX implementation
                                                    PBYTE   pb_BusType,
                                                    PCHAR   pc_IPAddress,
                                                    PCHAR   pc_SerialNumber,
                                                    // End CG 23/01/2006 : MX implementation
                                                    // Begin CG 16/11/2007 : MSX-E370x : not only check the serial number by open
                                                    PCHAR   pc_OriginalHeaderFileName,
                                                    // End CG 16/11/2007 : MSX-E370x : not only check the serial number by open
                                                    PDWORD pdw_BoardAddress,
                                                    PBYTE   pb_BoardInterrupt,
                                                    // Begin 31/03/03 CG : Add the read of the device Nbr Information
                                                    PBYTE pb_DeviceNbr,  
                                                    // End 31/03/03 CG : Add the read of the device Nbr Information
                                                    PCHAR   pc_PCISlotNumberInformation);

_INT_ i_UTILITY_SetPotentiometerValue        (DWORD                     dw_DriverHandle,
                                              BYTE                       b_PotisSelection,
                                              BYTE                       b_CallLevel,
                                              pstr_HardwareInformation  ps_HardwareInformation,
                                              pstr_PotisInformations    ps_HardwarePotis,
                                              WORD                       w_WriteValue);


// End: RH 21/11/01 1101/0218 -> 1101/0219 : Add APCI-1500 + APCI-3120 + APCI-3001

// Begin 28/03/03 CG : Export a function to read the header of the board and store it in a WORD array
_INT_   i_UTILITY_ReadBoardHeader  (INT i_SystemSelection,
                                    INT   i_BoardID,
                                    PWORD pw_BoardHeader,
                                    DWORD dw_BoardHeaderSize,
                                    PDWORD pdw_RealBoardHeaderSize);

_INT_ i_UTILITY_TestIfHeaderMustBeReadFromFile(PBYTE pb_ReadFromFile);

// End 28/03/03 CG : Export a function to read the header of the board and store it in a WORD array

// Begin 23/06/03 RH Add the read of the header of a NoHeaderOnBoard Board from a file

_INT_ i_UTILITY_TestIfNoHeaderOnBoard(INT    i_SystemSelection,
                                      INT    i_BoardID,
                                      PBYTE pb_NoHeaderOnBoard);

// End 23/06/03 RH Add the read of the header of a NoHeaderOnBoard Board from a file

// Begin CG 11/05/04 CG : Test if the information of the board can be read from the eeprom
_INT_ i_UTILITY_TestIfMainInformationHeaderOnBoard(INT    i_SystemSelection,
                                                   INT    i_BoardID,
                                                   PBYTE pb_MainInformationHeaderOnBoard);
// End CG 11/05/04 CG : Test if the information of the board can be read from the eeprom

#endif

